summaryrefslogtreecommitdiffstats
path: root/languages/ruby/debugger/breakpoint.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:51:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:51:21 -0600
commitb6ba5d642f3fc7d320e3d6f4650eb259a3a52b04 (patch)
tree76f49820693d443128d3720322ff1605e9bcd558 /languages/ruby/debugger/breakpoint.cpp
parent247f828db1b8dcdc9346c1568d81cfa00db99c9e (diff)
downloadtdevelop-b6ba5d642f3fc7d320e3d6f4650eb259a3a52b04.tar.gz
tdevelop-b6ba5d642f3fc7d320e3d6f4650eb259a3a52b04.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'languages/ruby/debugger/breakpoint.cpp')
-rw-r--r--languages/ruby/debugger/breakpoint.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/languages/ruby/debugger/breakpoint.cpp b/languages/ruby/debugger/breakpoint.cpp
index 9b3ed18d..8504ce93 100644
--- a/languages/ruby/debugger/breakpoint.cpp
+++ b/languages/ruby/debugger/breakpoint.cpp
@@ -70,7 +70,7 @@ Breakpoint::~Breakpoint()
TQString Breakpoint::dbgRemoveCommand() const
{
// if (dbgId_>0)
// return TQString("delete %1").tqarg(dbgId_); // gdb command - not translatable
return TQString();
}
@@ -161,9 +161,9 @@ TQString FilePosBreakpoint::dbgSetCommand() const
{
TQString cmdStr;
if (fileName_.isEmpty())
- cmdStr = TQString("break %1").tqarg(lineNo_); // gdb command - not translatable
+ cmdStr = TQString("break %1").arg(lineNo_); // gdb command - not translatable
else {
- cmdStr = TQString("break %1:%2").tqarg(fileName_).tqarg(lineNo_);
+ cmdStr = TQString("break %1:%2").arg(fileName_).arg(lineNo_);
}
if (isTemporary())
@@ -70,7 +70,7 @@ Breakpoint::~Breakpoint()
{
// if (dbgId_>0)
-// return TQString("delete %1").tqarg(dbgId_); // gdb command - not translatable
+// return TQString("delete %1").arg(dbgId_); // gdb command - not translatable
return TQString();
}